/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package com.rjconsultores.ventaboletos.service.impl;

import com.rjconsultores.ventaboletos.dao.EsquemaCorridaDAO;
import com.rjconsultores.ventaboletos.dao.EsquemaTramoDAO;
import com.rjconsultores.ventaboletos.dao.RutaCombinacionDAO;
import com.rjconsultores.ventaboletos.entidad.ClaseServicio;
import com.rjconsultores.ventaboletos.entidad.EsquemaAsiento;
import com.rjconsultores.ventaboletos.entidad.EsquemaCorrida;
import com.rjconsultores.ventaboletos.entidad.EsquemaOperacional;
import com.rjconsultores.ventaboletos.entidad.EsquemaTramo;
import com.rjconsultores.ventaboletos.entidad.Marca;
import com.rjconsultores.ventaboletos.entidad.Parada;
import com.rjconsultores.ventaboletos.entidad.ParadaEsquema;
import com.rjconsultores.ventaboletos.entidad.RolOperativo;
import com.rjconsultores.ventaboletos.entidad.Ruta;
import com.rjconsultores.ventaboletos.entidad.Tramo;
import com.rjconsultores.ventaboletos.service.EsquemaCorridaService;
import com.rjconsultores.ventaboletos.utilerias.UsuarioLogado;
import java.util.Calendar;
import java.util.Date;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * 
 * @author Rafius
 */
@Service("esquemaCorridaService")
public class EsquemaCorridaServiceImpl implements EsquemaCorridaService {

	@Autowired
	private EsquemaCorridaDAO esquemaCorridaDAO;
	@Autowired
	private RutaCombinacionDAO rutaCombinacionDAO;
	@Autowired
	private EsquemaTramoDAO esquemaTramoDAO;

	public List<EsquemaCorrida> obtenerTodos() {
		return esquemaCorridaDAO.obtenerTodos();
	}

	public EsquemaCorrida obtenerID(Integer id) {
		return esquemaCorridaDAO.obtenerID(id);
	}

	@Transactional
	public EsquemaCorrida suscribir(EsquemaCorrida entidad) {
		entidad.setUsuarioId(UsuarioLogado.getUsuarioLogado().getUsuarioId());
		entidad.setFecmodif(Calendar.getInstance().getTime());
		entidad.setActivo(Boolean.TRUE);

		return esquemaCorridaDAO.suscribir(entidad);
	}

	@Transactional
	public EsquemaCorrida actualizacion(EsquemaCorrida entidad) {
		entidad.setUsuarioId(UsuarioLogado.getUsuarioLogado().getUsuarioId());
		entidad.setFecmodif(Calendar.getInstance().getTime());
		entidad.setActivo(Boolean.TRUE);

		return esquemaCorridaDAO.actualizacion(entidad);
	}

	@Transactional
	public void borrar(EsquemaCorrida entidad) {
		entidad = (entidad.getEsquemacorridaId() == null) ? entidad : esquemaCorridaDAO.obtenerID(entidad.getEsquemacorridaId());
		for (EsquemaAsiento pricing : entidad.getEsquemaAsientoList()) {
			pricing.setUsuarioId(UsuarioLogado.getUsuarioLogado().getUsuarioId());
			pricing.setFecmodif(Calendar.getInstance().getTime());
			pricing.setActivo(Boolean.FALSE);
		}

		for (EsquemaTramo pricing : entidad.getEsquemaTramoList()) {
			pricing.setUsuarioId(UsuarioLogado.getUsuarioLogado().getUsuarioId());
			pricing.setFecmodif(Calendar.getInstance().getTime());
			pricing.setActivo(Boolean.FALSE);
		}

		entidad.setUsuarioId(UsuarioLogado.getUsuarioLogado().getUsuarioId());
		entidad.setFecmodif(Calendar.getInstance().getTime());
		entidad.setActivo(Boolean.FALSE);

		esquemaCorridaDAO.actualizacion(entidad);
	}

	public List<EsquemaCorrida> buscarPorEsquemaOperacional(EsquemaOperacional eo) {
		return esquemaCorridaDAO.buscarPorEsquemaOperacional(eo);
	}

	public List<EsquemaCorrida> buscar(Marca marca, RolOperativo rolOperativo,
			Ruta ruta, ClaseServicio claseServicio) {
		return esquemaCorridaDAO.buscar(marca, rolOperativo, ruta, claseServicio);
	}

	public List<EsquemaCorrida> buscar(EsquemaCorrida ec) {
		return esquemaCorridaDAO.buscar(ec);
	}

	@Transactional
	public void actualizaEsquemaTramo(List<ParadaEsquema> listParadaEsquema, EsquemaCorrida ec) {

		ec = this.obtenerID(ec.getEsquemacorridaId());
		if (ec.getEsquemaTramoList() != null) {
			for (EsquemaTramo et : ec.getEsquemaTramoList()) {
				et.setActivo(Boolean.FALSE);
				et.setUsuarioId(UsuarioLogado.getUsuarioLogado().getUsuarioId());
				et.setFecmodif(Calendar.getInstance().getTime());

				esquemaTramoDAO.actualizacion(et);
			}
		}

		for (int i = 0; (i < listParadaEsquema.size() - 1); i++) {
			Parada paradaOrigen = listParadaEsquema.get(i).getParada();
			Parada paradaDestino = listParadaEsquema.get(i + 1).getParada();

			Tramo t = rutaCombinacionDAO.busqueda(ec.getRuta(), paradaOrigen, paradaDestino);

			if (t == null) {
				throw new RuntimeException("No fue encontrado el tramo para el origen:" + paradaOrigen + " y destino:" + paradaDestino);
			}

			EsquemaTramo et = new EsquemaTramo();
			et.setActivo(Boolean.TRUE);
			et.setEsquemaCorrida(ec);
			et.setFecmodif(Calendar.getInstance().getTime());
			et.setNumsecuencia((short) (i + 1));
			et.setTiempoEstancia(listParadaEsquema.get(i + 1).getTiempoEstancia());
			et.setTramo(t);
			et.setUsuarioId(UsuarioLogado.getUsuarioLogado().getUsuarioId());

			esquemaTramoDAO.suscribir(et);
		}
	}

	@Override
	public List<EsquemaCorrida> buscaDentroVigencia(Date dataGeracao) {
		return esquemaCorridaDAO.buscaDentroVigencia(dataGeracao);
	}

	public boolean buscarEsquemaCorridaExisteTramo(Tramo tramo) {
		return esquemaCorridaDAO.buscarEsquemaCorridaExisteTramo(tramo);
	}

	@Override
	public List<Integer> existe(Ruta ruta, Integer paradaId) {
		return esquemaCorridaDAO.existe(ruta, paradaId);
	}
}
